<!--
 * @Author: BDFD
 * @Date: 2021-10-27 18:39:19
 * @LastEditTime: 2021-10-27 21:59:47
 * @LastEditors: Please set LastEditors
 * @Description: In User Settings Edit
 * @FilePath: \6.0-PyPI_Missing_Value_Table\README.md
-->

# Missing Value Table

Check the missing value in Data Frame

## Installation

`pip install table-nan-val`

## How to use it?

from table_nan_val import table_nan_val as tna

## License

copyright @ 2021 BDFD

This repository is licensed under the MIT license. See LICENSE for details.

### References

https://github.com/bdfd/6.1-PyPI_Missing_Value_Table
